==> nextcloud-24.0.4.tar.bz2: nextcloud/apps/theming/l10n/da.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Indlæser forhåndsvisning...",
    "Admin" : "Admin",
    "Saved" : "Gemt",
    "a safe home for all your data" : "Et sikket hjem til alt dit data",
    "Name cannot be empty" : "Navn må ikke være tomt",
    "The given name is too long" : "Navnet er for langt",
    "The given web address is too long" : "Webadressen er for lang",
    "The given web address is not a valid URL" : "Den angivne webadresse er ikke en gyldig URL",
    "The given legal notice address is too long" : "Den angivne juridiske meddelelsesadresse er for lang",
    "The given legal notice address is not a valid URL" : "Den angivne juridiske meddelelsesadresse er ikke en gyldig URL",
    "The given privacy policy address is too long" : "Den angivne adresse til privatlivspolitikken er for lang",
    "The given privacy policy address is not a valid URL" : "Den angivne adresse til privatlivspolitikken er ikke en gyldig URL",
    "The given slogan is too long" : "Sloganet er for langt",
    "The given color is invalid" : "Farven er ikke gyldig",
    "The file was uploaded" : "Filen blev uploadet",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "The file was only partially uploaded" : "Filen blev kun delvist uploadet",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "Could not write file to disk" : "Kunne ikke skrive fil til disk",
    "A PHP extension stopped the file upload" : "En PHP-udvidelse stoppede filoverførslen",
    "No file uploaded" : "Ingen fil uploadet",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Du bruger allerede et brugerdefineret tema. Theming app-indstillinger kan blive overskrevet af det.",
    "Theming" : "Temaer",
    "Dark theme" : "Mørkt tema",
    "Enable dark theme" : "Aktiver Mørkt tema",
    "Dyslexia font" : "Skrifftype for ordblinde",
    "Enable dyslexia font" : "aktiver skrifftype for ordblinde",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic er en gratis skrifttype designet til at undgå læsefejl pga. ordblindhed",
    "High contrast mode" : "Højkontrasttilstand",
    "Enable high contrast mode" : "aktiver højkontrasttilstand",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "En højkontrasttilstand letter navigationen. Presentation af lavere kvalitet, men tydeligere.",
    "Legal notice" : "Juridisk notits",
    "Privacy policy" : "Fortrolighedspolitik",
    "Adjust the Nextcloud theme" : "Juster Nextcloud-temaet",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universel adgang er meget vigtig for os. Vi følger web standarder og sikrer os at gøre alt tilgængeligt også uden mus, eller med hjælpesoftware såsom screenreaders. Vi søger at følge reglerne{guidelines}Web Content Accessibility Guidelines{linkend} 2.1 og AA endda med højt kontrast tema på AAA niveau.",
    "Open documentation" : "Åbn dokumentation",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Temaer gør det muligt nemt at tilpasse udseendet på din installation og understøttede klienter. Dette vil være synlig for alle brugere.",
    "Name" : "Navn",
    "Reset to default" : "Nulstil",
    "Web link" : "Web link",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Farve",
    "Logo" : "Logo",
    "Upload new logo" : "Upload nyt logo",
    "Login image" : "Login billede",
    "Upload new login background" : "Upload nyt login billede",
    "Remove background image" : "Fjern baggrundsbillede",
    "Advanced options" : "Avancerede indstillinger",
    "Legal notice link" : "Link til juridisk meddelelse",
    "Privacy policy link" : "Fortrolighedspolitik link",
    "Header logo" : "Overskriftslogo",
    "Upload new header logo" : "Upload nyt header-logo",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Upload nyt favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installer Imagemagick PHP udvidelsen med SVG support for automatisk at genererer favikoner baseret på the uploadede logo og farver."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/theming/l10n/da.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Indlæser forhåndsvisning...",
    "Admin" : "Admin",
    "Saved" : "Gemt",
    "a safe home for all your data" : "Et sikket hjem til alt dit data",
    "Name cannot be empty" : "Navn må ikke være tomt",
    "The given name is too long" : "Navnet er for langt",
    "The given web address is too long" : "Webadressen er for lang",
    "The given web address is not a valid URL" : "Den angivne webadresse er ikke en gyldig URL",
    "The given legal notice address is too long" : "Den angivne juridiske meddelelsesadresse er for lang",
    "The given legal notice address is not a valid URL" : "Den angivne juridiske meddelelsesadresse er ikke en gyldig URL",
    "The given privacy policy address is too long" : "Den angivne adresse til privatlivspolitikken er for lang",
    "The given privacy policy address is not a valid URL" : "Den angivne adresse til privatlivspolitikken er ikke en gyldig URL",
    "The given slogan is too long" : "Sloganet er for langt",
    "The given color is invalid" : "Farven er ikke gyldig",
    "The file was uploaded" : "Filen blev uploadet",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "The file was only partially uploaded" : "Filen blev kun delvist uploadet",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "Could not write file to disk" : "Kunne ikke skrive fil til disk",
    "A PHP extension stopped the file upload" : "En PHP-udvidelse stoppede filoverførslen",
    "No file uploaded" : "Ingen fil uploadet",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Du bruger allerede et brugerdefineret tema. Theming app-indstillinger kan blive overskrevet af det.",
    "Theming" : "Temaer",
    "Dark theme" : "Mørkt tema",
    "Enable dark theme" : "Aktiver Mørkt tema",
    "Dyslexia font" : "Skrifftype for ordblinde",
    "Enable dyslexia font" : "aktiver skrifftype for ordblinde",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic er en gratis skrifttype designet til at undgå læsefejl pga. ordblindhed",
    "High contrast mode" : "Højkontrasttilstand",
    "Enable high contrast mode" : "aktiver højkontrasttilstand",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "En højkontrasttilstand letter navigationen. Presentation af lavere kvalitet, men tydeligere.",
    "Legal notice" : "Juridisk notits",
    "Privacy policy" : "Fortrolighedspolitik",
    "Adjust the Nextcloud theme" : "Juster Nextcloud-temaet",
    "Keyboard shortcuts" : "Tastaturgenveje",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universel adgang er meget vigtig for os. Vi følger web standarder og sikrer os at gøre alt tilgængeligt også uden mus, eller med hjælpesoftware såsom screenreaders. Vi søger at følge reglerne{guidelines}Web Content Accessibility Guidelines{linkend} 2.1 og AA endda med højt kontrast tema på AAA niveau.",
    "Pick from Files" : "Vælg fra Filer",
    "Default image" : "Standardbillede",
    "Plain background" : "Standard baggrund",
    "Insert from {productName}" : "Indsæt fra {productName}",
    "Open documentation" : "Åbn dokumentation",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Temaer gør det muligt nemt at tilpasse udseendet på din installation og understøttede klienter. Dette vil være synlig for alle brugere.",
    "Name" : "Navn",
    "Reset to default" : "Nulstil",
    "Web link" : "Web link",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Farve",
    "Logo" : "Logo",
    "Upload new logo" : "Upload nyt logo",
    "Login image" : "Login billede",
    "Upload new login background" : "Upload nyt login billede",
    "Remove background image" : "Fjern baggrundsbillede",
    "Advanced options" : "Avancerede indstillinger",
    "Legal notice link" : "Link til juridisk meddelelse",
    "Privacy policy link" : "Fortrolighedspolitik link",
    "Header logo" : "Overskriftslogo",
    "Upload new header logo" : "Upload nyt header-logo",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Upload nyt favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installer Imagemagick PHP udvidelsen med SVG support for automatisk at genererer favikoner baseret på the uploadede logo og farver."
},
"nplurals=2; plural=(n != 1);");
